@@ -2,7 +2,7 @@
 ### Endemic-epidemic modelling for univariate or multivariate
 ### time series of infectious disease counts (data class "sts")
 ###
-### Copyright (C) 2010-2012 Michaela Paul, 2012-2016,2019-2023 Sebastian Meyer
+### Copyright (C) 2010-2012 Michaela Paul, 2012-2016,2019-2025 Sebastian Meyer
 ###
 ### This file is part of the R package "surveillance",
 ### free software under the terms of the GNU General Public License, version 2,
@@ -166,6 +166,12 @@ setControl <- function (control, stsObj)
   nUnit <- ncol(stsObj)
   if(nTime <= 2) stop("too few observations")
 
+  ## epidemic components are disabled by default: warn if settings lack 'f'
+  for (comp in c("ar", "ne"))
+      if (length(control[[comp]]) && !hasName(control[[comp]], "f"))
+          warning("settings for component \"", comp, "\" lack a formula; ",
+                  "it is disabled by default")
+
   ## arguments in 'control' override any corresponding default arguments
   defaultControl <- eval(formals(hhh4)$control)
   environment(defaultControl$ar$f) <- environment(defaultControl$ne$f) <-
@@ -338,7 +344,7 @@ isInModel <- function(formula, name=deparse(substitute(formula)))
 fe <- function(x,          # covariate
                unitSpecific = FALSE, # TRUE means which = rep.int(TRUE, nUnits)
                which=NULL, # NULL = overall, vector with booleans = unit-specific
-               initial=NULL) # vector of inital values for parameters
+               initial=NULL) # vector of initial values for parameters
 {
   stsObj <- get("stsObj", envir=parent.frame(1), inherits=TRUE) #checkFormula()
   nTime <- nrow(stsObj)
@@ -553,7 +559,7 @@ checkFormula <- function(f, component, data, stsObj)
 ## Create function (pars, type = "response") which
 ## returns the weighted sum of time-lagged counts of neighbours
 ## (or its derivates, if type = "gradient" or type = "hessian").
-## For type="reponse", this is a nTime x nUnits matrix (like Y),
+## For type="response", this is a nTime x nUnits matrix (like Y),
 ## otherwise a list of such matrices,
 ## which for the gradient has length length(pars) and
 ## length(pars)*(length(pars)+1)/2 for the hessian.
@@ -1036,7 +1042,7 @@ penScore <- function(theta, sd.corr, model)
 
     for(i in seq_len(nGroups)){
       comp <- term["offsetComp",i][[1]]
-      Xit<- term["terms",i][[1]] # eiter 1 or a matrix with values
+      Xit<- term["terms",i][[1]] # either 1 or a matrix with values
       if(is.matrix(Xit)){
         Xit <- Xit[subset,,drop=FALSE]
       }
@@ -1295,7 +1301,7 @@ penFisher <- function(theta, sd.corr, model, attributes=FALSE)
       # parameter group belongs to which components
       comp.i <- term["offsetComp",i][[1]]
       # get covariate value
-      Xit <- term["terms",i][[1]] # eiter 1 or a matrix with values
+      Xit <- term["terms",i][[1]] # either 1 or a matrix with values
       if(is.matrix(Xit)){
         Xit <- Xit[subset,,drop=FALSE]
       }
@@ -1356,7 +1362,7 @@ penFisher <- function(theta, sd.corr, model, attributes=FALSE)
       for(j in i:nGroups){
         comp.j <- term["offsetComp",j][[1]]
 
-        Xjt <- term["terms",j][[1]] # eiter 1 or a matrix with values
+        Xjt <- term["terms",j][[1]] # either 1 or a matrix with values
         if(is.matrix(Xjt)){
           Xjt <- Xjt[subset,,drop=FALSE]
         }
@@ -2028,9 +2034,10 @@ fitHHH <- function(theta, sd.corr, model,
 
   ## Let's go
   if (verbose>0) {
-      cat(as.character(Sys.time()), ":",
-          if (dimRE == 0) "Optimization of regression parameters" else
-          "Iterative optimization of regression & variance parameters", "\n")
+      if (verbose > 1) utils::timestamp()
+      cat(if (dimRE == 0) "Optimization of regression parameters"
+          else "Iterative optimization of regression & variance parameters",
+          "\n", sep = "")
   }
 
   if (dimRE == 0) { # optimization of regression coefficients only
@@ -2098,9 +2105,9 @@ fitHHH <- function(theta, sd.corr, model,
   }
 
   if(verbose > 0) {
-    cat("\n")
-    cat(as.character(Sys.time()), ":", if (convergence==0)
-        "Optimization converged" else "Optimization DID NOT CONVERGE", "\n\n")
+    cat("\n", if (convergence==0) "Optimization converged"
+        else "Optimization DID NOT CONVERGE", "\n", sep = "")
+    if (verbose > 1) utils::timestamp()
   }
 
   ll     <- penLogLik(theta, sd.corr, model)
@@ -2118,7 +2125,7 @@ fitHHH <- function(theta, sd.corr, model,
 
 
 
-## check analytical score functions and Fisher informations for
+## check analytical score functions and Fisher information for
 ## a given model (the result of interpretControl(control, stsObj))
 ## and given parameters theta (regression par.) and sd.corr (variance par.).
 ## This is a wrapper around functionality of the numDeriv and maxLik packages.
