@@ -14,6 +14,7 @@
 wrap.algo <- function(sts, algo, control,
                       control.hook=function(k, control) return(control),
                       verbose=TRUE,...) {
+  chkDots(...)
   stopifnot(is.vector(control[["range"]], mode = "numeric"))
 
   #Number of time series
@@ -25,7 +26,7 @@ wrap.algo <- function(sts, algo, control,
 
   #Loop over all regions
   for (k in 1:nAreas) {
-    if (verbose) {
+    if (verbose && nAreas > 1) {
       cat("Running ",algo," on area ",k," out of ",nAreas,"\n")
     }
 
@@ -45,10 +46,13 @@ wrap.algo <- function(sts, algo, control,
   #Control object needs only to be set once
   sts@control <- survRes.k$control
 
+  #Fix invalid data name (= deparse(disProg.k) from last iteration)
+  sts@control$data <- "sts"
+
   #Set correct theta0t matrix for all
   sts@control$theta0t <- control$theta0t
 
-  #Reduce sts object to only those obervations in range
+  #Reduce sts object to only those observations in range
   sts <- sts[control$range, ]
 
   return(sts)
@@ -92,7 +96,7 @@ hmm <- function(sts, control=list(range=NULL, noStates=2, trend=TRUE, noHarmonic
 
 
 #Cusum wrapper
-cusum <- function(sts,  control = list(range=range, k=1.04, h=2.26, m=NULL, trans="standard",alpha=NULL),...) {
+cusum <- function(sts, control = list(range=range, k=1.04, h=2.26, m=NULL, trans="standard", alpha=NULL, reset=FALSE), ...) {
   wrap.algo(sts,algo="algo.cusum",control=control,...)
 }
 
