@@ -74,6 +74,21 @@ test_that("score vector and Fisher info agree with numerical approximations", if
     test(W_np(maxlag = 3, truncate = TRUE, normalize = TRUE, from0 = TRUE))
 })
 
+test_that("alternative optimizers give equivalent results", {
+    ctrl_nlm <- list(method = "nlm", check.analyticals = TRUE)
+    expect_equal(
+        update(measlesFit, optimizer = list(regression = ctrl_nlm),
+               use.estimates = FALSE),
+        measlesFit, tolerance = 1e-5, ignore = "control"
+    )
+    ctrl_BFGS <- list(method = "BFGS", reltol = 1e-12)
+    expect_equal(
+        update(measlesFit, optimizer = list(regression = ctrl_BFGS),
+               use.estimates = FALSE),
+        measlesFit, tolerance = 1e-5, ignore = "control"
+    )
+})
+
 test_that("automatic and manual normalization are equivalent", {
     ## check for equivalent functions
     for (type in c("powerlaw", "np")) {
@@ -105,6 +120,13 @@ test_that("automatic and manual normalization are equivalent", {
                  tolerance = 1e-6) # increased to pass on 32-bit Windows
 })
 
+test_that("unnamed plot() 'type' argument is not passed down", {
+    expect_length(plot(measlesFit, "neweights", plotter = list), 1)
+    ## failed in surveillance <= 1.24.1; actual use case:
+    ## R> plot(measlesFit, "neweights", exclude = NULL)
+    ## Error in get(as.character(FUN), mode = "function", envir = envir) :
+    ##   object 'neweights' of mode 'function' was not found
+})
 
 measlesWeserEms2 <- measlesWeserEms
 neighbourhood(measlesWeserEms2) <- neighbourhood(measlesWeserEms2) + 1L
